@@ -1,22 +1,22 @@
 """OpenAPI X-Model extension factories module"""
+
 from dataclasses import make_dataclass
-from pydoc import ErrorDuringImport
 from pydoc import locate
 from typing import Any
 from typing import Dict
 from typing import Iterable
-from typing import Optional
 from typing import Type
 
+from jsonschema_path import SchemaPath
+
 from openapi_core.extensions.models.types import Field
-from openapi_core.spec import Spec
 
 
 class DictFactory:
     base_class = dict
 
     def create(
-        self, schema: Spec, fields: Iterable[Field]
+        self, schema: SchemaPath, fields: Iterable[Field]
     ) -> Type[Dict[Any, Any]]:
         return self.base_class
 
@@ -24,7 +24,7 @@ class DictFactory:
 class ModelFactory(DictFactory):
     def create(
         self,
-        schema: Spec,
+        schema: SchemaPath,
         fields: Iterable[Field],
     ) -> Type[Any]:
         name = schema.getkey("x-model")
@@ -37,7 +37,7 @@ class ModelFactory(DictFactory):
 class ModelPathFactory(ModelFactory):
     def create(
         self,
-        schema: Spec,
+        schema: SchemaPath,
         fields: Iterable[Field],
     ) -> Any:
         model_class_path = schema.getkey("x-model-path")
